@@ -19,12 +19,12 @@ package org.drools.workbench.screens.guided.dtable.client.editor.page;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Optional;
 import java.util.function.Consumer;
 
-import com.google.gwt.dev.util.collect.HashMap;
 import com.google.gwt.event.dom.client.ClickEvent;
 import com.google.gwt.event.dom.client.ClickHandler;
 import com.google.gwt.event.logical.shared.ValueChangeEvent;
@@ -119,6 +119,9 @@ public class ColumnsPagePresenterTest {
     @Mock
     private ColumnManagementView actionsPanel;
 
+    @Mock
+    private ShowRuleNameOptionPresenter showRuleNameOptionPresenter;
+
     @Mock
     private VerticalPanel verticalPanel;
 
@@ -148,7 +151,8 @@ public class ColumnsPagePresenterTest {
                                                  deleteColumnManagementAnchorWidgets,
                                                  attributeColumnConfigRow,
                                                  conditionsPanel,
-                                                 actionsPanel));
+                                                 actionsPanel,
+                                                 showRuleNameOptionPresenter));
 
         doReturn(modeller).when(presenter).getModeller();
     }
@@ -168,6 +172,7 @@ public class ColumnsPagePresenterTest {
 
         doNothing().when(presenter).setupAccordion();
         doNothing().when(presenter).setupRuleInheritance();
+        doNothing().when(presenter).setupUseRuleNames();
         doNothing().when(presenter).setupColumnsNoteInfo(modeller);
         doNothing().when(presenter).setupConditionsPanel(modeller);
         doNothing().when(presenter).setupActionsPanel(modeller);
