@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,8 +18,9 @@ package org.drools.workbench.screens.guided.dtable.client.widget.table;
 
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.List;
+import java.util.Optional;
 import java.util.Set;
+
 import javax.enterprise.event.Event;
 
 import com.ait.lienzo.client.core.event.NodeMouseMoveHandler;
@@ -32,22 +33,13 @@ import com.google.gwt.event.dom.client.MouseDownHandler;
 import com.google.gwt.event.shared.HandlerRegistration;
 import com.google.gwt.user.client.Command;
 import org.drools.workbench.models.datamodel.workitems.PortableWorkDefinition;
-import org.drools.workbench.models.guided.dtable.shared.model.ActionCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.AttributeCol52;
-import org.drools.workbench.models.guided.dtable.shared.model.BaseColumn;
-import org.drools.workbench.models.guided.dtable.shared.model.CompositeColumn;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
-import org.drools.workbench.models.guided.dtable.shared.model.MetadataCol52;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableColumnSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTablePinnedEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshActionsPanelEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshAttributesPanelEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshConditionsPanelEvent;
-import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.RefreshMetaDataPanelEvent;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.popovers.ColumnHeaderPopOver;
-import org.drools.workbench.screens.guided.dtable.client.wizard.column.NewGuidedDecisionTableColumnWizard;
+import org.drools.workbench.screens.guided.dtable.client.widget.table.themes.GuidedDecisionTableRenderer;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
@@ -67,11 +59,22 @@ import org.uberfire.ext.wires.core.grids.client.model.impl.BaseGridData;
 import org.uberfire.ext.wires.core.grids.client.widget.grid.renderers.columns.GridColumnRenderer;
 import org.uberfire.ext.wires.core.grids.client.widget.layer.GridLayer;
 import org.uberfire.mocks.EventSourceMock;
-import org.uberfire.mvp.ParameterizedCommand;
 import org.uberfire.mvp.PlaceRequest;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.reset;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(LienzoMockitoTestRunner.class)
 public class GuidedDecisionTableModellerPresenterTest {
@@ -79,9 +82,6 @@ public class GuidedDecisionTableModellerPresenterTest {
     @Mock
     private GuidedDecisionTableModellerView view;
 
-    @Mock
-    private ManagedInstance<NewGuidedDecisionTableColumnWizard> wizardManagedInstance;
-
     @Mock
     private GridLayer gridLayer;
 
@@ -139,8 +139,7 @@ public class GuidedDecisionTableModellerPresenterTest {
                                                                                                       contextMenuSupport,
                                                                                                       updateRadarEvent,
                                                                                                       pinnedEvent,
-                                                                                                      columnHeaderPopOver,
-                                                                                                      wizardManagedInstance);
+                                                                                                      columnHeaderPopOver);
         presenter = spy(wrapped);
 
         when(dtablePresenterProvider.get()).thenReturn(dtablePresenter);
@@ -151,12 +150,15 @@ public class GuidedDecisionTableModellerPresenterTest {
     private GuidedDecisionTableView.Presenter makeDecisionTable() {
         final GuidedDecisionTableView.Presenter dtPresenter = mock(GuidedDecisionTableView.Presenter.class);
         final GuidedDecisionTableView dtView = mock(GuidedDecisionTableView.class);
+        final GuidedDecisionTableRenderer renderer = mock(GuidedDecisionTableRenderer.class);
         final GridData dtData = new BaseGridData();
 
         when(dtPresenter.getView()).thenReturn(dtView);
         when(dtPresenter.getAccess()).thenReturn(mock(GuidedDecisionTablePresenter.Access.class));
         when(dtPresenter.getModel()).thenReturn(mock(GuidedDecisionTable52.class));
         when(dtView.getModel()).thenReturn(dtData);
+        when(dtView.getRenderer()).thenReturn(renderer);
+        when(renderer.getHeaderCaptionWidth()).thenReturn(200.0);
 
         return dtPresenter;
     }
@@ -290,67 +292,19 @@ public class GuidedDecisionTableModellerPresenterTest {
         assertNotNull(afterRemovalCommand);
         afterRemovalCommand.execute();
 
-        verify(view,
-               times(1)).setEnableColumnCreation(eq(false));
-        verify(view,
-               times(1)).refreshAttributeWidget(eq(Collections.emptyList()));
-        verify(view,
-               times(1)).refreshMetaDataWidget(eq(Collections.emptyList()));
-        verify(view,
-               times(1)).refreshConditionsWidget(eq(Collections.emptyList()));
-        verify(view,
-               times(1)).refreshActionsWidget(eq(Collections.emptyList()));
-        verify(view,
-               times(1)).refreshColumnsNote(eq(false));
         verify(dtPresenter,
                times(1)).onClose();
         verify(presenter,
                times(1)).removeLinksForDecisionTable(eq(dtPresenter));
     }
 
-    @Test
-    public void onLockStatusUpdatedWithNullDecisionTable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-
-        when(presenter.getActiveDecisionTable()).thenReturn(dtPresenter);
-
-        presenter.onLockStatusUpdated(null);
-
-        verify(presenter,
-               never()).refreshDefinitionsPanel(any(GuidedDecisionTableView.Presenter.class));
-    }
-
-    @Test
-    public void onLockStatusUpdatedWithActiveDecisionTable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-
-        when(presenter.getActiveDecisionTable()).thenReturn(dtPresenter);
-
-        presenter.onLockStatusUpdated(dtPresenter);
-
-        verify(presenter,
-               times(1)).refreshDefinitionsPanel(eq(dtPresenter));
-    }
-
-    @Test
-    public void onLockStatusUpdatedWithAnotherActiveDecisionTable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-
-        when(presenter.getActiveDecisionTable()).thenReturn(mock(GuidedDecisionTableView.Presenter.class));
-
-        presenter.onLockStatusUpdated(dtPresenter);
-
-        verify(presenter,
-               never()).refreshDefinitionsPanel(eq(dtPresenter));
-    }
-
     @Test
     public void isActiveDecisionTableEditableIsReadOnly() {
         final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
         final GuidedDecisionTablePresenter.Access access = new GuidedDecisionTablePresenter.Access();
         access.setReadOnly(true);
 
-        when(presenter.getActiveDecisionTable()).thenReturn(dtPresenter);
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.of(dtPresenter));
         when(dtPresenter.getAccess()).thenReturn(access);
 
         assertFalse(presenter.isActiveDecisionTableEditable());
@@ -362,7 +316,7 @@ public class GuidedDecisionTableModellerPresenterTest {
         final GuidedDecisionTablePresenter.Access access = new GuidedDecisionTablePresenter.Access();
         access.setReadOnly(false);
 
-        when(presenter.getActiveDecisionTable()).thenReturn(dtPresenter);
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.of(dtPresenter));
         when(dtPresenter.getAccess()).thenReturn(access);
 
         assertTrue(presenter.isActiveDecisionTableEditable());
@@ -374,7 +328,7 @@ public class GuidedDecisionTableModellerPresenterTest {
         final GuidedDecisionTablePresenter.Access access = new GuidedDecisionTablePresenter.Access();
         access.setLock(GuidedDecisionTablePresenter.Access.LockedBy.CURRENT_USER);
 
-        when(presenter.getActiveDecisionTable()).thenReturn(dtPresenter);
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.of(dtPresenter));
         when(dtPresenter.getAccess()).thenReturn(access);
 
         assertTrue(presenter.isActiveDecisionTableEditable());
@@ -386,30 +340,17 @@ public class GuidedDecisionTableModellerPresenterTest {
         final GuidedDecisionTablePresenter.Access access = new GuidedDecisionTablePresenter.Access();
         access.setLock(GuidedDecisionTablePresenter.Access.LockedBy.OTHER_USER);
 
-        when(presenter.getActiveDecisionTable()).thenReturn(dtPresenter);
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.of(dtPresenter));
         when(dtPresenter.getAccess()).thenReturn(access);
 
         assertFalse(presenter.isActiveDecisionTableEditable());
     }
 
     @Test
-    public void onInsertColumnWithNullActiveDecisionTable() {
-        presenter.onInsertColumn();
+    public void isActiveDecisionTableEditableWhenNoActiveDecisionTale() {
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.empty());
 
-        verify(view,
-               never()).onInsertColumn();
-    }
-
-    @Test
-    public void onInsertColumnWithNonNullActiveDecisionTable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-
-        when(presenter.getActiveDecisionTable()).thenReturn(dtPresenter);
-
-        presenter.onInsertColumn();
-
-        verify(view,
-               times(1)).onInsertColumn();
+        assertFalse(presenter.isActiveDecisionTableEditable());
     }
 
     @Test
@@ -487,7 +428,6 @@ public class GuidedDecisionTableModellerPresenterTest {
         final GuidedDecisionTableView.Presenter dtPresenter1 = makeDecisionTable();
         final GuidedDecisionTableView.Presenter dtPresenter2 = makeDecisionTable();
         final DecisionTableSelectedEvent event = new DecisionTableSelectedEvent(dtPresenter1);
-        final List<String> parentRuleNames = Collections.emptyList();
 
         when(gridLayer.isGridPinned()).thenReturn(true);
 
@@ -497,26 +437,12 @@ public class GuidedDecisionTableModellerPresenterTest {
             add(dtPresenter2);
         }});
 
-        final ArgumentCaptor<ParameterizedCommand> parentRuleNamesCommandCaptor = ArgumentCaptor.forClass(ParameterizedCommand.class);
-
         presenter.onDecisionTableSelected(event);
 
         verify(dtPresenter1,
                times(1)).initialiseAnalysis();
-        verify(presenter,
-               times(1)).refreshDefinitionsPanel(eq(dtPresenter1));
         verify(view,
                times(1)).select(dtPresenter1.getView());
-
-        verify(dtPresenter1,
-               times(1)).getPackageParentRuleNames(parentRuleNamesCommandCaptor.capture());
-        final ParameterizedCommand parentRuleNamesCommand = parentRuleNamesCommandCaptor.getValue();
-        assertNotNull(parentRuleNamesCommand);
-        parentRuleNamesCommand.execute(parentRuleNames);
-
-        verify(view,
-               times(1)).refreshRuleInheritance(any(String.class),
-                                                eq(parentRuleNames));
         verify(gridLayer,
                times(1)).flipToGridWidget(eq(dtPresenter1.getView()));
     }
@@ -527,7 +453,6 @@ public class GuidedDecisionTableModellerPresenterTest {
         final GuidedDecisionTableView.Presenter dtPresenter1 = makeDecisionTable();
         final GuidedDecisionTableView.Presenter dtPresenter2 = makeDecisionTable();
         final DecisionTableSelectedEvent event = new DecisionTableSelectedEvent(dtPresenter1);
-        final List<String> parentRuleNames = Collections.emptyList();
 
         when(presenter.isDecisionTableAvailable(eq(dtPresenter1))).thenReturn(true);
         when(presenter.getAvailableDecisionTables()).thenReturn(new HashSet<GuidedDecisionTableView.Presenter>() {{
@@ -535,28 +460,80 @@ public class GuidedDecisionTableModellerPresenterTest {
             add(dtPresenter2);
         }});
 
-        final ArgumentCaptor<ParameterizedCommand> parentRuleNamesCommandCaptor = ArgumentCaptor.forClass(ParameterizedCommand.class);
+        presenter.onDecisionTableSelected(event);
+
+        verify(dtPresenter1,
+               times(1)).initialiseAnalysis();
+        verify(view,
+               times(1)).select(dtPresenter1.getView());
+        verify(gridLayer,
+               never()).flipToGridWidget(any(GuidedDecisionTableView.class));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void onDecisionTableSelectedWithOtherActiveDecisionTable() {
+        final GuidedDecisionTableView.Presenter dtPresenter1 = makeDecisionTable();
+        final GuidedDecisionTableView.Presenter dtPresenter2 = makeDecisionTable();
+        final DecisionTableSelectedEvent event = new DecisionTableSelectedEvent(dtPresenter1);
+
+        when(presenter.isDecisionTableAvailable(eq(dtPresenter1))).thenReturn(true);
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.of(dtPresenter2));
+        when(presenter.getAvailableDecisionTables()).thenReturn(new HashSet<GuidedDecisionTableView.Presenter>() {{
+            add(dtPresenter1);
+            add(dtPresenter2);
+        }});
 
         presenter.onDecisionTableSelected(event);
 
         verify(dtPresenter1,
                times(1)).initialiseAnalysis();
-        verify(presenter,
-               times(1)).refreshDefinitionsPanel(eq(dtPresenter1));
         verify(view,
                times(1)).select(dtPresenter1.getView());
+    }
 
-        verify(dtPresenter1,
-               times(1)).getPackageParentRuleNames(parentRuleNamesCommandCaptor.capture());
-        final ParameterizedCommand parentRuleNamesCommand = parentRuleNamesCommandCaptor.getValue();
-        assertNotNull(parentRuleNamesCommand);
-        parentRuleNamesCommand.execute(parentRuleNames);
+    @Test
+    @SuppressWarnings("unchecked")
+    public void onDecisionTableSelectedWithSameActiveDecisionTable() {
+        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
+        final DecisionTableSelectedEvent event = new DecisionTableSelectedEvent(dtPresenter);
 
-        verify(view,
-               times(1)).refreshRuleInheritance(any(String.class),
-                                                eq(parentRuleNames));
-        verify(gridLayer,
-               never()).flipToGridWidget(any(GuidedDecisionTableView.class));
+        when(presenter.isDecisionTableAvailable(eq(dtPresenter))).thenReturn(true);
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.of(dtPresenter));
+        when(presenter.getAvailableDecisionTables()).thenReturn(Collections.singleton(dtPresenter));
+
+        presenter.onDecisionTableSelected(event);
+
+        verify(dtPresenter, never()).initialiseAnalysis();
+        verify(view, never()).select(any(GuidedDecisionTableView.class));
+    }
+
+    @Test
+    public void onDecisionTableSelectedNoneSelected() {
+        final DecisionTableSelectedEvent event = DecisionTableSelectedEvent.NONE;
+
+        presenter.onDecisionTableSelected(event);
+
+        assertFalse(presenter.getActiveDecisionTable().isPresent());
+
+        verify(presenter,
+               never()).doDecisionTableSelected(any(GuidedDecisionTableView.Presenter.class));
+    }
+
+    @Test
+    public void onDecisionTableSelectedNotAvailable() {
+        final GuidedDecisionTableView.Presenter dtPresenter1 = makeDecisionTable();
+        final GuidedDecisionTableView.Presenter dtPresenter2 = makeDecisionTable();
+        final DecisionTableSelectedEvent event = new DecisionTableSelectedEvent(dtPresenter1);
+
+        when(presenter.getAvailableDecisionTables()).thenReturn(Collections.singleton(dtPresenter2));
+
+        presenter.onDecisionTableSelected(event);
+
+        assertFalse(presenter.getActiveDecisionTable().isPresent());
+
+        verify(presenter,
+               never()).doDecisionTableSelected(any(GuidedDecisionTableView.Presenter.class));
     }
 
     @Test
@@ -570,130 +547,6 @@ public class GuidedDecisionTableModellerPresenterTest {
                times(1)).selectLinkedColumn(eq(gridColumn));
     }
 
-    @Test
-    public void onRefreshAttributesPanelEventWithDecisionTableAvailable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-        final List<AttributeCol52> columns = Collections.emptyList();
-        final RefreshAttributesPanelEvent event = new RefreshAttributesPanelEvent(dtPresenter,
-                                                                                  columns);
-
-        when(presenter.isDecisionTableAvailable(dtPresenter)).thenReturn(true);
-
-        presenter.onRefreshAttributesPanelEvent(event);
-
-        verify(view,
-               times(1)).refreshAttributeWidget(eq(columns));
-    }
-
-    @Test
-    @SuppressWarnings("unchecked")
-    public void onRefreshAttributesPanelEventWithDecisionTableUnavailable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-        final List<AttributeCol52> columns = Collections.emptyList();
-        final RefreshAttributesPanelEvent event = new RefreshAttributesPanelEvent(dtPresenter,
-                                                                                  columns);
-
-        when(presenter.isDecisionTableAvailable(dtPresenter)).thenReturn(false);
-
-        presenter.onRefreshAttributesPanelEvent(event);
-
-        verify(view,
-               never()).refreshAttributeWidget(any(List.class));
-    }
-
-    @Test
-    public void onRefreshMetaDataPanelEventWithDecisionTableAvailable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-        final List<MetadataCol52> columns = Collections.emptyList();
-        final RefreshMetaDataPanelEvent event = new RefreshMetaDataPanelEvent(dtPresenter,
-                                                                              columns);
-
-        when(presenter.isDecisionTableAvailable(dtPresenter)).thenReturn(true);
-
-        presenter.onRefreshMetaDataPanelEvent(event);
-
-        verify(view,
-               times(1)).refreshMetaDataWidget(eq(columns));
-    }
-
-    @Test
-    @SuppressWarnings("unchecked")
-    public void onRefreshMetaDataPanelEventWithDecisionTableUnavailable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-        final List<MetadataCol52> columns = Collections.emptyList();
-        final RefreshMetaDataPanelEvent event = new RefreshMetaDataPanelEvent(dtPresenter,
-                                                                              columns);
-
-        when(presenter.isDecisionTableAvailable(dtPresenter)).thenReturn(false);
-
-        presenter.onRefreshMetaDataPanelEvent(event);
-
-        verify(view,
-               never()).refreshMetaDataWidget(any(List.class));
-    }
-
-    @Test
-    public void onRefreshConditionsPanelEventWithDecisionTableAvailable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-        final List<CompositeColumn<? extends BaseColumn>> columns = Collections.emptyList();
-        final RefreshConditionsPanelEvent event = new RefreshConditionsPanelEvent(dtPresenter,
-                                                                                  columns);
-
-        when(presenter.isDecisionTableAvailable(dtPresenter)).thenReturn(true);
-
-        presenter.onRefreshConditionsPanelEvent(event);
-
-        verify(view,
-               times(1)).refreshConditionsWidget(eq(columns));
-    }
-
-    @Test
-    @SuppressWarnings("unchecked")
-    public void onRefreshConditionsPanelEventWithDecisionTableUnavailable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-        final List<CompositeColumn<? extends BaseColumn>> columns = Collections.emptyList();
-        final RefreshConditionsPanelEvent event = new RefreshConditionsPanelEvent(dtPresenter,
-                                                                                  columns);
-
-        when(presenter.isDecisionTableAvailable(dtPresenter)).thenReturn(false);
-
-        presenter.onRefreshConditionsPanelEvent(event);
-
-        verify(view,
-               never()).refreshConditionsWidget(any(List.class));
-    }
-
-    @Test
-    public void onRefreshActionsPanelEventWithDecisionTableAvailable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-        final List<ActionCol52> columns = Collections.emptyList();
-        final RefreshActionsPanelEvent event = new RefreshActionsPanelEvent(dtPresenter,
-                                                                            columns);
-
-        when(presenter.isDecisionTableAvailable(dtPresenter)).thenReturn(true);
-
-        presenter.onRefreshActionsPanelEvent(event);
-
-        verify(view,
-               times(1)).refreshActionsWidget(eq(columns));
-    }
-
-    @Test
-    @SuppressWarnings("unchecked")
-    public void onRefreshActionsPanelEventWithDecisionTableUnavailable() {
-        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
-        final List<ActionCol52> columns = Collections.emptyList();
-        final RefreshActionsPanelEvent event = new RefreshActionsPanelEvent(dtPresenter,
-                                                                            columns);
-
-        when(presenter.isDecisionTableAvailable(dtPresenter)).thenReturn(false);
-
-        presenter.onRefreshActionsPanelEvent(event);
-
-        verify(view,
-               never()).refreshActionsWidget(any(List.class));
-    }
-
     @Test
     public void updateRadar() {
         presenter.updateRadar();
@@ -706,6 +559,9 @@ public class GuidedDecisionTableModellerPresenterTest {
     public void onViewPinnedIsPinned() {
         final ArgumentCaptor<DecisionTablePinnedEvent> pinnedEventCaptor = ArgumentCaptor.forClass(DecisionTablePinnedEvent.class);
 
+        GuidedDecisionTableView.Presenter value = makeDecisionTable();
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.of(value));
+
         presenter.onViewPinned(true);
 
         verify(pinnedEvent,
@@ -716,12 +572,16 @@ public class GuidedDecisionTableModellerPresenterTest {
         assertEquals(presenter,
                      pinnedEvent.getPresenter());
         assertTrue(pinnedEvent.isPinned());
+        verify(view).setPinnedModeIndicatorVisibility(true, 210);
     }
 
     @Test
     public void onViewPinnedIsNotPinned() {
+        final GuidedDecisionTableView.Presenter dtPresenter = makeDecisionTable();
         final ArgumentCaptor<DecisionTablePinnedEvent> pinnedEventCaptor = ArgumentCaptor.forClass(DecisionTablePinnedEvent.class);
 
+        when(presenter.getActiveDecisionTable()).thenReturn(Optional.of(dtPresenter));
+
         presenter.onViewPinned(false);
 
         verify(pinnedEvent,
@@ -732,6 +592,7 @@ public class GuidedDecisionTableModellerPresenterTest {
         assertEquals(presenter,
                      pinnedEvent.getPresenter());
         assertFalse(pinnedEvent.isPinned());
+        verify(view).setPinnedModeIndicatorVisibility(false, 210);
     }
 
     @Test
@@ -829,110 +690,4 @@ public class GuidedDecisionTableModellerPresenterTest {
         verify(dtPresenter2Column2,
                never()).setLink(any());
     }
-
-    @Test
-    public void testHandlePermissionsWhenGuidedDecisionTableHasEditableColumns() {
-
-        doReturn(true).when(dtablePresenter).hasEditableColumns();
-
-        presenter.handlePermissions(dtablePresenter);
-
-        verify(view).enableColumnOperationsMenu();
-    }
-
-    @Test
-    public void testHandlePermissionsWhenGuidedDecisionTableDoesNotHaveEditableColumns() {
-
-        doReturn(false).when(dtablePresenter).hasEditableColumns();
-
-        presenter.handlePermissions(dtablePresenter);
-
-        verify(view, never()).enableColumnOperationsMenu();
-    }
-
-    @Test
-    public void testIsColumnCreationEnabledWhenGuidedDecisionTableIsEditableAndHasEditableColumns() {
-
-        doReturn(model).when(dtablePresenter).getModel();
-        doReturn(false).when(dtablePresenter).isReadOnly();
-        doReturn(true).when(dtablePresenter).hasEditableColumns();
-
-        final boolean isEnabled = presenter.isColumnCreationEnabled(dtablePresenter);
-
-        assertTrue(isEnabled);
-    }
-
-    @Test
-    public void testIsColumnCreationEnabledWhenGuidedDecisionTableDoesNotHaveEditableColumns() {
-
-        doReturn(model).when(dtablePresenter).getModel();
-        doReturn(false).when(dtablePresenter).isReadOnly();
-        doReturn(false).when(dtablePresenter).hasEditableColumns();
-
-        final boolean isEnabled = presenter.isColumnCreationEnabled(dtablePresenter);
-
-        assertFalse(isEnabled);
-    }
-
-    @Test
-    public void testIsColumnCreationEnabledWhenGuidedDecisionTableIsNotEditable() {
-
-        doReturn(model).when(dtablePresenter).getModel();
-        doReturn(true).when(dtablePresenter).isReadOnly();
-        doReturn(true).when(dtablePresenter).hasEditableColumns();
-
-        final boolean isEnabled = presenter.isColumnCreationEnabled(dtablePresenter);
-
-        assertFalse(isEnabled);
-    }
-
-    @Test
-    public void testIsColumnCreationEnabledWhenGuidedDecisionTableIsNotEditableNeitherHasEditableColumns() {
-
-        doReturn(model).when(dtablePresenter).getModel();
-        doReturn(true).when(dtablePresenter).isReadOnly();
-        doReturn(false).when(dtablePresenter).hasEditableColumns();
-
-        final boolean isEnabled = presenter.isColumnCreationEnabled(dtablePresenter);
-
-        assertFalse(isEnabled);
-    }
-
-    @Test
-    public void testRefreshDefinitionsPanel() {
-
-        doReturn(model).when(dtablePresenter).getModel();
-        doReturn(true).when(presenter).isColumnCreationEnabled(dtablePresenter);
-
-        presenter.refreshDefinitionsPanel(dtablePresenter);
-
-        verify(view).setEnableColumnCreation(true);
-        verify(view).refreshAttributeWidget(model.getAttributeCols());
-        verify(view).refreshMetaDataWidget(model.getMetadataCols());
-        verify(view).refreshConditionsWidget(model.getConditions());
-        verify(view).refreshActionsWidget(model.getActionCols());
-        verify(view).refreshColumnsNote(dtablePresenter.hasColumnDefinitions());
-    }
-
-    @Test
-    public void testIsColumnCreationEnabledToActiveDecisionTableWhenActiveDecisionTableIsNull() {
-
-        doReturn(null).when(presenter).getActiveDecisionTable();
-        doReturn(true).when(presenter).isColumnCreationEnabled(any());
-
-        final boolean isEnabled = presenter.isColumnCreationEnabledToActiveDecisionTable();
-
-        assertFalse(isEnabled);
-    }
-
-    @Test
-    public void testIsColumnCreationEnabledToActiveDecisionTableWhenActiveDecisionTableIsNotNull() {
-
-        doReturn(dtablePresenter).when(presenter).getActiveDecisionTable();
-        doReturn(true).when(presenter).isColumnCreationEnabled(dtablePresenter);
-
-        final boolean isEnabled = presenter.isColumnCreationEnabledToActiveDecisionTable();
-
-        assertTrue(isEnabled);
-    }
 }
