@@ -71,9 +71,9 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
 
     @Override
     public void selectProperty(String factName, List<String> propertyParts) {
-        final ListGroupItemView listGroupItemView = listGroupItemViewMap.get(factName);
-        if (!listGroupItemView.isShown()) {
-            onToggleRowExpansion(listGroupItemView, false);
+        final ListGroupItemView instanceListGroupItemView = listGroupItemViewMap.get(factName);
+        if (!instanceListGroupItemView.isShown()) {
+            onToggleRowExpansion(instanceListGroupItemView, false);
         }
         String key;
         for (int i = 1; i < propertyParts.size(); i++) {
@@ -86,7 +86,9 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
         }
         key = factName + "." + String.join(".", propertyParts);
         if (fieldItemPresenter.fieldItemMap.containsKey(key)) {
-            fieldItemPresenter.fieldItemMap.get(key).onFieldElementClick();
+            fieldItemPresenter.fieldItemMap.get(key).onFieldElementSelected();
+        } else {
+            instanceListGroupItemView.showCheck(true);
         }
     }
 
@@ -196,9 +198,10 @@ public class ListGroupItemPresenter implements ListGroupItemView.Presenter {
             toPopulate.setFactNameAndType(factName, factModelTree.getFactName()); // the name of the property differ from the type of the factModelTree: this means that we are populating children of the class
         }
         String fullPath = parentPath.isEmpty() ? factName : parentPath + "." + factName;
-        factModelTree.getSimpleProperties().forEach((key, value) -> toPopulate.addFactField(fieldItemPresenter.getLIElement(fullPath, factName, key, value)));
-        factModelTree.getExpandableProperties().forEach(
-                (key, value) -> toPopulate.addExpandableFactField(getDivElement(fullPath, key, value)));
+        factModelTree.getSimpleProperties().entrySet().stream().sorted(Map.Entry.comparingByKey()).forEach(entry ->
+                toPopulate.addFactField(fieldItemPresenter.getLIElement(fullPath, factName, entry.getKey(), entry.getValue().getTypeName(), entry.getValue().getPropertyTypeNameToVisualize())));
+        factModelTree.getExpandableProperties().entrySet().stream().sorted(Map.Entry.comparingByValue()).forEach(entry ->
+                 toPopulate.addExpandableFactField(getDivElement(fullPath, entry.getKey(), entry.getValue())));
     }
 
     /**
