@@ -33,6 +33,7 @@ import org.drools.workbench.screens.scenariosimulation.kogito.client.dmn.KogitoS
 import org.drools.workbench.screens.scenariosimulation.kogito.client.dmo.KogitoAsyncPackageDataModelOracle;
 import org.drools.workbench.screens.scenariosimulation.kogito.client.editor.strategies.KogitoDMNDataManagementStrategy;
 import org.drools.workbench.screens.scenariosimulation.kogito.client.editor.strategies.KogitoDMODataManagementStrategy;
+import org.drools.workbench.screens.scenariosimulation.kogito.client.handlers.ScenarioSimulationKogitoDocksHandler;
 import org.drools.workbench.screens.scenariosimulation.kogito.client.popup.ScenarioSimulationKogitoCreationPopupPresenter;
 import org.gwtbootstrap3.client.ui.NavTabs;
 import org.gwtbootstrap3.client.ui.TabListItem;
@@ -44,10 +45,12 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.kogito.client.editor.BaseKogitoEditor;
 import org.kie.workbench.common.kogito.client.editor.MultiPageEditorContainerView;
 import org.kie.workbench.common.kogito.client.resources.i18n.KogitoClientConstants;
+import org.kie.workbench.common.widgets.client.docks.AuthoringEditorDock;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
+import org.mockito.internal.util.reflection.Whitebox;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.backend.vfs.PathFactory;
@@ -57,6 +60,7 @@ import org.uberfire.client.views.pfly.multipage.MultiPageEditorViewImpl;
 import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
 import org.uberfire.client.workbench.widgets.multipage.Page;
 import org.uberfire.mvp.Command;
+import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 import org.uberfire.workbench.model.menu.Menus;
@@ -66,6 +70,7 @@ import static org.junit.Assert.assertTrue;
 import static org.mockito.BDDMockito.willThrow;
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyBoolean;
+import static org.mockito.Matchers.anyString;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Matchers.isA;
 import static org.mockito.Mockito.never;
@@ -127,6 +132,12 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
     private Promise.PromiseExecutorCallbackFn.ResolveCallbackFn<Object> resolveCallbackFnMock;
     @Mock
     private Promise.PromiseExecutorCallbackFn.RejectCallbackFn rejectCallbackFnMock;
+    @Mock
+    private PlaceRequest placeRequestMock;
+    @Mock
+    private ScenarioSimulationKogitoDocksHandler scenarioSimulationKogitoDocksHandlerMock;
+    @Mock
+    private AuthoringEditorDock authoringEditorDockMock;
     @Captor
     private ArgumentCaptor<DataManagementStrategy> dataManagementStrategyCaptor;
     @Captor
@@ -135,6 +146,8 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
     private ArgumentCaptor<RemoteCallback> remoteCallbackArgumentCaptor;
     @Captor
     private ArgumentCaptor<Path> pathArgumentCaptor;
+    @Captor
+    private ArgumentCaptor<Promise.PromiseExecutorCallbackFn> promiseExecutorCallbackFnArgumentCaptor;
 
     private ScenarioSimulationEditorKogitoWrapper scenarioSimulationEditorKogitoWrapperSpy;
     private Path path = PathFactory.newPath("file.scesim", "path/");
@@ -156,7 +169,6 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
         when(navBarsMock.getWidget(1)).thenReturn(editorItemMock);
         when(navBarsMock.getWidget(2)).thenReturn(backgroundItemMock);
         when(scenarioSimulationKogitoCreationPopupPresenterMock.getSelectedPath()).thenReturn("selected");
-
         when(translationServiceMock.getTranslation(KogitoClientConstants.KieEditorWrapperView_EditTabTitle)).thenReturn(KogitoClientConstants.KieEditorWrapperView_EditTabTitle);
         scenarioSimulationEditorKogitoWrapperSpy = spy(new ScenarioSimulationEditorKogitoWrapper() {
             {
@@ -167,6 +179,8 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
                 this.translationService = translationServiceMock;
                 this.scenarioSimulationKogitoCreationPopupPresenter = scenarioSimulationKogitoCreationPopupPresenterMock;
                 this.scenarioSimulationBuilder = kogitoScenarioSimulationBuilderMock;
+                this.authoringWorkbenchDocks = authoringEditorDockMock;
+                this.scenarioSimulationKogitoDocksHandler = scenarioSimulationKogitoDocksHandlerMock;
             }
 
             @Override
@@ -174,6 +188,11 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
                 return multiPageEditorContainerViewMock;
             }
 
+            @Override
+            protected void marshallContent(ScenarioSimulationModel scenarioSimulationModel, Promise.PromiseExecutorCallbackFn.ResolveCallbackFn<String> resolveCallbackFn) {
+                // JSInterops logic, can't be tested
+            }
+
             @Override
             protected void resetEditorPages() {
                 //Do nothing
@@ -191,8 +210,10 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
     @Test
     public void getContent() {
         scenarioSimulationEditorKogitoWrapperSpy.getContent();
-        verify(scenarioSimulationEditorPresenterMock, times(1)).getModel();
-        verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).transform(eq(scenarioSimulationModelMock));
+        verify(promisesMock, times(1)).create(promiseExecutorCallbackFnArgumentCaptor.capture());
+        promiseExecutorCallbackFnArgumentCaptor.getValue().onInvoke(resolveCallBackMock, rejectCallbackFnMock);
+        verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).prepareContent(eq(resolveCallBackMock),
+                                                                                                       eq(rejectCallbackFnMock));
     }
 
     @Test
@@ -205,6 +226,22 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
         assertEquals("path/", pathArgumentCaptor.getValue().toURI());
     }
 
+    @Test
+    public void prepareContent() {
+        scenarioSimulationEditorKogitoWrapperSpy.prepareContent(resolveCallBackMock, rejectCallbackFnMock);
+        verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).synchronizeColumnsDimension(eq(simulationGridPanelMock), eq(backgroundGridPanelMock));
+        verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).marshallContent(eq(scenarioSimulationModelMock), eq(resolveCallBackMock));
+        verify(scenarioSimulationEditorPresenterMock, never()).sendNotification(any(), any());
+    }
+
+    @Test
+    public void prepareContent_Exception() {
+        willThrow(Exception.class).given(scenarioSimulationEditorKogitoWrapperSpy).marshallContent(any(), any());
+        scenarioSimulationEditorKogitoWrapperSpy.prepareContent(resolveCallBackMock, rejectCallbackFnMock);
+        verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).synchronizeColumnsDimension(eq(simulationGridPanelMock), eq(backgroundGridPanelMock));
+        verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).marshallContent(eq(scenarioSimulationModelMock), eq(resolveCallBackMock));
+        verify(scenarioSimulationEditorPresenterMock, times(1)).sendNotification(anyString(), eq(NotificationEvent.NotificationType.ERROR));
+    }
 
     @Test
     public void manageContentFileWithoutPath() {
@@ -274,31 +311,25 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
         verify(scenarioSimulationEditorPresenterMock, times(1)).onEditTabSelected();
     }
 
-    @Test
-    public void wrappedSave() {
-        scenarioSimulationEditorKogitoWrapperSpy.wrappedSave("commit");
-        verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).synchronizeColumnsDimension(eq(simulationGridPanelMock),
-                                                                                                                    eq(backgroundGridPanelMock));
-    }
-
-    @Test
-    public void transform() {
-        scenarioSimulationEditorKogitoWrapperSpy.transform(scenarioSimulationModelMock);
-        verify(promisesMock, times(1)).create(isA(Promise.PromiseExecutorCallbackFn.class));
-    }
-
     @Test
     public void makeMenuBar() {
         scenarioSimulationEditorPresenterMock.makeMenuBar(fileMenuBuilderMock);
         verify(scenarioSimulationEditorPresenterMock, times(1)).makeMenuBar(eq(fileMenuBuilderMock));
     }
 
+    @Test
+    public void onStartup() {
+        Whitebox.setInternalState(scenarioSimulationEditorKogitoWrapperSpy, "multiPageEditorContainerView", multiPageEditorContainerViewMock);
+        scenarioSimulationEditorKogitoWrapperSpy.onStartup(placeRequestMock);
+        verify(authoringEditorDockMock, times(1)).setup(eq("AuthoringPerspective"), eq(placeRequestMock));
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setWrapper(eq(scenarioSimulationEditorKogitoWrapperSpy));
+    }
+
     @Test
     public void gotoPath() {
         scenarioSimulationEditorKogitoWrapperSpy.gotoPath(path);
         verify(kogitoAsyncPackageDataModelOracleMock, times(1)).init(eq(path));
-        verify(scenarioSimulationEditorPresenterMock, times(1)).init(eq(scenarioSimulationEditorKogitoWrapperSpy),
-                                                                                          isA(ObservablePath.class));
+        verify(scenarioSimulationEditorPresenterMock, times(1)).setPath(isA(ObservablePath.class));
         assertEquals(path, scenarioSimulationEditorKogitoWrapperSpy.getCurrentPath());
     }
 
@@ -314,6 +345,7 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
         when(settingsMock.getType()).thenReturn(ScenarioSimulationModel.Type.RULE);
         when(scenarioSimulationEditorPresenterMock.getJsonModel(eq(scenarioSimulationModelMock))).thenReturn(JSON_MODEL);
         scenarioSimulationEditorKogitoWrapperSpy.onModelSuccessCallbackMethod(scenarioSimulationModelMock);
+        verify(scenarioSimulationEditorPresenterMock, times(1)).sendNotification(eq(ScenarioSimulationEditorConstants.INSTANCE.ruleScenarioNotSupportedNotification()), eq(NotificationEvent.NotificationType.WARNING), eq(false));
         verify(scenarioSimulationEditorPresenterMock, times(1)).setPackageName(eq(ScenarioSimulationEditorKogitoWrapper.DEFAULT_PACKAGE));
         verify(((BaseKogitoEditor) scenarioSimulationEditorKogitoWrapperSpy), times(1)).setOriginalContentHash(eq(JSON_MODEL.hashCode()));
         verify(scenarioSimulationEditorPresenterMock, times(1)).getModelSuccessCallbackMethod(dataManagementStrategyCaptor.capture(), eq(scenarioSimulationModelMock));
@@ -326,6 +358,7 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
         when(settingsMock.getType()).thenReturn(ScenarioSimulationModel.Type.DMN);
         when(scenarioSimulationEditorPresenterMock.getJsonModel(eq(scenarioSimulationModelMock))).thenReturn(JSON_MODEL);
         scenarioSimulationEditorKogitoWrapperSpy.onModelSuccessCallbackMethod(scenarioSimulationModelMock);
+        verify(scenarioSimulationEditorPresenterMock, never()).sendNotification(any(), any(), anyBoolean());
         verify(scenarioSimulationEditorPresenterMock, times(1)).setPackageName(eq(ScenarioSimulationEditorKogitoWrapper.DEFAULT_PACKAGE));
         verify(((BaseKogitoEditor)scenarioSimulationEditorKogitoWrapperSpy), times(1)).setOriginalContentHash(eq(JSON_MODEL.hashCode()));
         verify(scenarioSimulationEditorPresenterMock, times(1)).getModelSuccessCallbackMethod(dataManagementStrategyCaptor.capture(), eq(scenarioSimulationModelMock));
@@ -420,4 +453,16 @@ public class ScenarioSimulationEditorKogitoWrapperTest {
         verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).gotoPath(eq(path));
         verify(scenarioSimulationEditorKogitoWrapperSpy, times(1)).unmarshallContent(isA(String.class));
     }
+
+    @Test
+    public void getScenarioSimulationDocksHandler() {
+        assertEquals(scenarioSimulationKogitoDocksHandlerMock,
+                     scenarioSimulationEditorKogitoWrapperSpy.getScenarioSimulationDocksHandler());
+    }
+
+    @Test
+    public void getScenarioSimulationEditorPresenter() {
+        assertEquals(scenarioSimulationEditorPresenterMock,
+                     scenarioSimulationEditorKogitoWrapperSpy.getScenarioSimulationEditorPresenter());
+    }
 }
